@@ -1,6 +1,8 @@
 package consoleserver
 
 import (
+	corev1 "k8s.io/api/core/v1"
+
 	operatorv1 "github.com/openshift/api/operator/v1"
 	"github.com/openshift/console-operator/pkg/api"
 	"github.com/openshift/console-operator/pkg/console/subresource/util"
@@ -9,8 +11,9 @@ import (
 )
 
 const (
-	clientSecretFilePath    = "/var/oauth-config/clientSecret"
-	oauthEndpointCAFilePath = "/var/run/secrets/kubernetes.io/serviceaccount/ca.crt"
+	clientSecretFilePath       = "/var/oauth-config/clientSecret"
+	defaultIngressCertFilePath = "/var/default-ingress-cert/ca-bundle.crt"
+	oauthEndpointCAFilePath    = "/var/run/secrets/kubernetes.io/serviceaccount/ca.crt"
 	// serving info
 	certFilePath = "/var/serving-cert/tls.crt"
 	keyFilePath  = "/var/serving-cert/tls.key"
@@ -28,14 +31,17 @@ const (
 // set only some values:
 //   b.Host().Brand("").Config()
 type ConsoleServerCLIConfigBuilder struct {
-	host              string
-	logoutRedirectURL string
-	brand             operatorv1.Brand
-	docURL            string
-	apiServerURL      string
-	statusPageID      string
-	customProductName string
-	customLogoFile    string
+	host                       string
+	logoutRedirectURL          string
+	brand                      operatorv1.Brand
+	docURL                     string
+	apiServerURL               string
+	statusPageID               string
+	customProductName          string
+	customLogoFile             string
+	CAFile                     string
+	monitoring                 map[string]string
+	customHostnameRedirectPort int
 }
 
 func (b *ConsoleServerCLIConfigBuilder) Host(host string) *ConsoleServerCLIConfigBuilder {
@@ -68,21 +74,46 @@ func (b *ConsoleServerCLIConfigBuilder) CustomLogoFile(customLogoFile string) *C
 	}
 	return b
 }
-
+func (b *ConsoleServerCLIConfigBuilder) CustomHostnameRedirectPort(redirect bool) *ConsoleServerCLIConfigBuilder {
+	// If custom hostname is set on the console operator config,
+	// set the port under which the console backend will listen
+	// for redirect.
+	if redirect {
+		b.customHostnameRedirectPort = api.RedirectContainerTargetPort
+	}
+	return b
+}
 func (b *ConsoleServerCLIConfigBuilder) StatusPageID(id string) *ConsoleServerCLIConfigBuilder {
 	b.statusPageID = id
 	return b
 }
 
+func (b *ConsoleServerCLIConfigBuilder) DefaultIngressCert(useDefaultDefaultIngressCert bool) *ConsoleServerCLIConfigBuilder {
+	if useDefaultDefaultIngressCert {
+		b.CAFile = oauthEndpointCAFilePath
+		return b
+	}
+	b.CAFile = defaultIngressCertFilePath
+	return b
+}
+
+func (b *ConsoleServerCLIConfigBuilder) Monitoring(monitoringConfig *corev1.ConfigMap) *ConsoleServerCLIConfigBuilder {
+	if monitoringConfig != nil {
+		b.monitoring = monitoringConfig.Data
+	}
+	return b
+}
+
 func (b *ConsoleServerCLIConfigBuilder) Config() Config {
 	return Config{
-		Kind:          "ConsoleConfig",
-		APIVersion:    "console.openshift.io/v1",
-		Auth:          b.authServer(),
-		ClusterInfo:   b.clusterInfo(),
-		Customization: b.customization(),
-		ServingInfo:   b.servingInfo(),
-		Providers:     b.providers(),
+		Kind:           "ConsoleConfig",
+		APIVersion:     "console.openshift.io/v1",
+		Auth:           b.authServer(),
+		ClusterInfo:    b.clusterInfo(),
+		Customization:  b.customization(),
+		ServingInfo:    b.servingInfo(),
+		Providers:      b.providers(),
+		MonitoringInfo: b.monitoringInfo(),
 	}
 }
 
@@ -97,11 +128,17 @@ func (b *ConsoleServerCLIConfigBuilder) ConfigYAML() (consoleConfigYAML []byte,
 }
 
 func (b *ConsoleServerCLIConfigBuilder) servingInfo() ServingInfo {
-	return ServingInfo{
+	conf := ServingInfo{
 		BindAddress: "https://[::]:8443",
 		CertFile:    certFilePath,
 		KeyFile:     keyFilePath,
 	}
+
+	if b.customHostnameRedirectPort != 0 {
+		conf.RedirectPort = b.customHostnameRedirectPort
+	}
+
+	return conf
 }
 
 func (b *ConsoleServerCLIConfigBuilder) clusterInfo() ClusterInfo {
@@ -118,11 +155,44 @@ func (b *ConsoleServerCLIConfigBuilder) clusterInfo() ClusterInfo {
 	return conf
 }
 
+func (b *ConsoleServerCLIConfigBuilder) monitoringInfo() MonitoringInfo {
+	conf := MonitoringInfo{}
+	if len(b.monitoring) > 0 {
+		var monitoringURLs MonitoringInfo
+		urls, err := yaml.Marshal(b.monitoring)
+		if err != nil {
+			return conf
+		}
+		err = yaml.Unmarshal(urls, &monitoringURLs)
+		if err != nil {
+			return conf
+		}
+		if len(monitoringURLs.AlertmanagerPublicURL) > 0 {
+			conf.AlertmanagerPublicURL = monitoringURLs.AlertmanagerPublicURL
+		}
+		if len(monitoringURLs.GrafanaPublicURL) > 0 {
+			conf.GrafanaPublicURL = monitoringURLs.GrafanaPublicURL
+		}
+		if len(monitoringURLs.PrometheusPublicURL) > 0 {
+			conf.PrometheusPublicURL = monitoringURLs.PrometheusPublicURL
+		}
+		if len(monitoringURLs.ThanosPublicURL) > 0 {
+			conf.ThanosPublicURL = monitoringURLs.ThanosPublicURL
+		}
+	}
+	return conf
+}
+
 func (b *ConsoleServerCLIConfigBuilder) authServer() Auth {
+	// we need this fallback due to the way our unit test are structured,
+	// where the ConsoleServerCLIConfigBuilder object is being instantiated empty
+	if b.CAFile == "" {
+		b.CAFile = oauthEndpointCAFilePath
+	}
 	conf := Auth{
 		ClientID:            api.OpenShiftConsoleName,
 		ClientSecretFile:    clientSecretFilePath,
-		OAuthEndpointCAFile: oauthEndpointCAFilePath,
+		OAuthEndpointCAFile: b.CAFile,
 	}
 	if len(b.logoutRedirectURL) > 0 {
 		conf.LogoutRedirect = b.logoutRedirectURL
